@@ -629,7 +629,6 @@ def kde_distributions(
     n_cols=1,
     w_pad=1.0,
     h_pad=1.0,
-    text_wrap=50,
     image_path_png=None,
     image_path_svg=None,
     image_filename=None,
@@ -644,6 +643,7 @@ def kde_distributions(
     binwidth=None,  # Parameter to control the width of bins
     label_fontsize=10,  # Fontsize control for labels
     tick_fontsize=10,  # Fontsize control for tick labels
+    text_wrap=50,
     disable_sci_notation=False,  # Toggle for scientific notation
     stat="density",  # Control the aggregate statistic for histograms
     xlim=None,
@@ -705,9 +705,6 @@ def kde_distributions(
     h_pad : float, optional (default=1.0)
         Height padding between subplots.
 
-    text_wrap : int, optional (default=50)
-        Maximum width of the title text before wrapping.
-
     image_path_png : str, optional
         Directory path to save the PNG image of the overall distribution plots.
 
@@ -748,6 +745,12 @@ def kde_distributions(
     label_fontsize : int, optional (default=10)
         Font size for axis labels, including xlabel, ylabel, and tick marks.
 
+    tick_fontsize : int, optional (default=10)
+        Font size for tick labels on the axes.
+
+    text_wrap : int, optional (default=50)
+        Maximum width of the title text before wrapping.
+
     disable_sci_notation : bool, optional (default=False)
         Toggle to disable scientific notation on axes.
 
@@ -1081,6 +1084,7 @@ def stacked_crosstab_plot(
     show_legend=True,
     label_fontsize=12,
     tick_fontsize=10,
+    text_wrap=50,
     remove_stacks=False,
     xlim=None,
     ylim=None,
@@ -1091,8 +1095,8 @@ def stacked_crosstab_plot(
     This function allows users to create stacked bar plots (or regular bar plots
     if stacks are removed) and corresponding crosstabs for specific columns
     in a DataFrame. It provides options to customize the appearance, including
-    font sizes for axis labels and tick labels, and to choose between regular
-    or normalized plots.
+    font sizes for axis labels, tick labels, and title text wrapping, and to
+    choose between regular or normalized plots.
 
     Parameters:
     -----------
@@ -1169,6 +1173,9 @@ def stacked_crosstab_plot(
     tick_fontsize : int, optional (default=10)
         Font size for tick labels on the axes.
 
+    text_wrap : int, optional (default=50)
+        The maximum width of the title text before wrapping.
+
     remove_stacks : bool, optional (default=False)
         If True, removes stacks and creates a regular bar plot using only
         the `col` parameter. Only works when `plot_type` is set to 'regular'.
@@ -1303,7 +1310,10 @@ def stacked_crosstab_plot(
                 if ylim:
                     ax0.set_ylim(ylim)
 
-                ax0.set_title(title1, fontsize=label_fontsize)
+                ax0.set_title(
+                    "\n".join(textwrap.wrap(title1, width=text_wrap)),
+                    fontsize=label_fontsize,  # Ensure label_fontsize is applied
+                )
                 ax0.tick_params(axis="both", labelsize=tick_fontsize)
 
                 if show_legend:
@@ -1334,15 +1344,20 @@ def stacked_crosstab_plot(
                     crosstabdest.plot(
                         kind=kind,
                         stacked=True,
-                        title=title1,
                         ax=axes[0] if plot_type == "both" else axes,
                         color=color,
                         width=width,
                         rot=rot,
-                        fontsize=12,
-                        logy=logscale,  # Apply log scale if logscale is True
+                        fontsize=label_fontsize,  # Apply label_fontsize here
                     )
+
+                    # Explicitly set the title with the desired font size
                     ax0 = axes[0] if plot_type == "both" else axes
+                    ax0.set_title(
+                        "\n".join(textwrap.wrap(title1, width=text_wrap)),
+                        # Ensure the title font size is consistent
+                        fontsize=label_fontsize,
+                    )
 
                     if kind == "barh":
                         ax0.set_xlabel(ylabel1, fontsize=label_fontsize)
@@ -1360,8 +1375,9 @@ def stacked_crosstab_plot(
                     # Set tick fontsize
                     ax0.tick_params(axis="both", labelsize=tick_fontsize)
 
+                    # Set legend font size to match label_fontsize
                     if show_legend:
-                        ax0.legend(legend, fontsize=12)
+                        ax0.legend(legend, fontsize=label_fontsize)
                     else:
                         ax0.legend().remove()
 
@@ -1380,16 +1396,23 @@ def stacked_crosstab_plot(
                     crosstabdestnorm.plot(
                         kind=kind,
                         stacked=True,
-                        title=title2,
                         ylabel="Percentage",
                         ax=axes[1] if plot_type == "both" else axes,
                         color=color,
                         width=width,
                         rot=rot,
-                        fontsize=12,
-                        logy=logscale,  # Apply log scale if logscale is True
+                        # This controls axis labels and ticks
+                        fontsize=label_fontsize,
+                        logy=logscale,
                     )
+
+                    # Explicitly set the title with the desired font size
                     ax1 = axes[1] if plot_type == "both" else axes
+                    ax1.set_title(
+                        "\n".join(textwrap.wrap(title2, width=text_wrap)),
+                        # This should now control the title font size
+                        fontsize=label_fontsize,
+                    )
 
                     if kind == "barh":
                         ax1.set_xlabel(ylabel2, fontsize=label_fontsize)
@@ -1407,8 +1430,9 @@ def stacked_crosstab_plot(
                     # Set tick fontsize
                     ax1.tick_params(axis="both", labelsize=tick_fontsize)
 
+                    # Set legend font size to match label_fontsize
                     if show_legend:
-                        ax1.legend(legend, fontsize=12)
+                        ax1.legend(legend, fontsize=label_fontsize)
                     else:
                         ax1.legend().remove()
 
@@ -1502,34 +1526,76 @@ def box_violin_plot(
     grid_figsize=None,  # Parameter to specify figure size for grid plots
     label_fontsize=12,  # Parameter to control axis label fontsize
     tick_fontsize=10,  # Parameter to control tick label fontsize
+    text_wrap=50,  # Add text_wrap parameter
     xlim=None,  # New parameter for setting x-axis limits
     ylim=None,  # New parameter for setting y-axis limits
 ):
     """
-    Create and save individual boxplots or violin plots, an entire grid of plots,
-    or both for given metrics and comparisons, with optional axis limits.
+    Create and save individual boxplots or violin plots, an entire grid
+    of plots, or both for given metrics and comparisons, with optional
+    axis limits.
 
     Parameters:
-    - df: DataFrame containing the data.
-    - metrics_list: List of metric names (columns in df) to plot.
-    - metrics_boxplot_comp: List of comparison categories (columns in df).
-    - n_rows: Number of rows in the subplot grid.
-    - n_cols: Number of columns in the subplot grid.
-    - image_path_png: Optional directory path to save .png images.
-    - image_path_svg: Optional directory path to save .svg images.
-    - save_plots: String, "all", "individual", or "grid" to control saving plots.
-    - show_legend: Boolean, True if showing the legend in the plots.
-    - plot_type: String, "boxplot" or "violinplot" to specify the type of plot.
-    - xlabel_rot: Integer, rotation angle for x-axis labels.
-    - show_plot: String, "individual", "grid", or "both" to control plot display.
-    - rotate_plot: Boolean, True if rotating (pivoting) the plots.
-    - individual_figsize: Tuple or list, width and height of the figure for
-      individual plots.
-    - grid_figsize: Tuple or list, width and height of the figure for grid plots.
-    - label_fontsize: Integer, fontsize for axis labels.
-    - tick_fontsize: Integer, fontsize for axis tick labels.
-    - xlim: Tuple, specifying the limits of the x-axis.
-    - ylim: Tuple, specifying the limits of the y-axis.
+    -----------
+    df : pandas.DataFrame
+        The DataFrame containing the data.
+
+    metrics_list : list
+        List of metric names (columns in df) to plot.
+
+    metrics_boxplot_comp : list
+        List of comparison categories (columns in df).
+
+    n_rows : int
+        Number of rows in the subplot grid.
+
+    n_cols : int
+        Number of columns in the subplot grid.
+
+    image_path_png : str, optional
+        Directory path to save .png images.
+
+    image_path_svg : str, optional
+        Directory path to save .svg images.
+
+    save_plots : str, optional
+        String, "all", "individual", or "grid" to control saving plots.
+
+    show_legend : bool, optional (default=True)
+        True if showing the legend in the plots.
+
+    plot_type : str, optional (default='boxplot')
+        String, "boxplot" or "violinplot" to specify the type of plot.
+
+    xlabel_rot : int, optional (default=0)
+        Rotation angle for x-axis labels.
+
+    show_plot : str, optional (default='both')
+        String, "individual", "grid", or "both" to control plot display.
+
+    rotate_plot : bool, optional (default=False)
+        True if rotating (pivoting) the plots.
+
+    individual_figsize : tuple or list, optional
+        Width and height of the figure for individual plots.
+
+    grid_figsize : tuple or list, optional
+        Width and height of the figure for grid plots.
+
+    label_fontsize : int, optional (default=12)
+        Font size for axis labels.
+
+    tick_fontsize : int, optional (default=10)
+        Font size for axis tick labels.
+
+    text_wrap : int, optional (default=50)
+        The maximum width of the title text before wrapping.
+
+    xlim : tuple, optional
+        Tuple specifying the limits of the x-axis.
+
+    ylim : tuple, optional
+        Tuple specifying the limits of the y-axis.
     """
 
     # Check for valid show_plot values
@@ -1609,7 +1675,11 @@ def box_violin_plot(
                     palette=palette,
                     dodge=False,
                 )
-                plt.title(f"Distribution of {met_list} by {met_comp}")
+                title = f"Distribution of {met_list} by {met_comp}"
+                plt.title(
+                    "\n".join(textwrap.wrap(title, width=text_wrap)),
+                    fontsize=label_fontsize,
+                )
                 plt.xlabel(
                     met_list if rotate_plot else met_comp,
                     fontsize=label_fontsize,
@@ -1679,7 +1749,11 @@ def box_violin_plot(
                     palette=palette,
                     dodge=False,
                 )
-                ax.set_title(f"Distribution of {met_list} by {met_comp}")
+                title = f"Distribution of {met_list} by {met_comp}"
+                ax.set_title(
+                    "\n".join(textwrap.wrap(title, width=text_wrap)),
+                    fontsize=label_fontsize,
+                )
                 ax.set_xlabel(
                     met_list if rotate_plot else met_comp,
                     fontsize=label_fontsize,
@@ -1749,6 +1823,7 @@ def scatter_fit_plot(
     grid_figsize=None,  # Parameter to specify figure size for grid plots
     label_fontsize=12,  # Parameter to control axis label fontsize
     tick_fontsize=10,  # Parameter to control tick label fontsize
+    text_wrap=50,  # Parameter to control wrapping of text in title
     add_best_fit_line=False,  # Parameter to add best fit line
     scatter_color="C0",  # Parameter to control the color of scattered points
     best_fit_linecolor="red",  # Parameter to control color of best fit line
@@ -1763,9 +1838,9 @@ def scatter_fit_plot(
     ylim=None,  # Parameter to set y-axis limits
 ):
     """
-    Create and save scatter plots or a grid of scatter plots for given x_vars
-    and y_vars, with an optional best fit line and customizable point color,
-    size, and markers.
+    Create and save scatter plots or a grid of scatter plots for given
+    x_vars and y_vars, with an optional best fit line and customizable
+    point color, size, and markers.
 
     Parameters:
     -----------
@@ -1817,6 +1892,9 @@ def scatter_fit_plot(
     tick_fontsize : int, optional (default=10)
         Font size for axis tick labels.
 
+    text_wrap : int, optional (default=50)
+        The maximum width of the title text before wrapping.
+
     add_best_fit_line : bool, optional (default=False)
         Whether to add a best fit line to the scatter plots.
 
@@ -1958,7 +2036,11 @@ def scatter_fit_plot(
                 title = f"{y_var} vs {x_var}"
                 if show_correlation:
                     title += f" ($r$ = {r_value:.2f})"
-                plt.title(title)
+                # Use label_fontsize for title
+                plt.title(
+                    "\n".join(textwrap.wrap(title, width=text_wrap)),
+                    fontsize=label_fontsize,
+                )
                 plt.xlabel(
                     y_var if rotate_plot else x_var,
                     fontsize=label_fontsize,
@@ -2045,7 +2127,11 @@ def scatter_fit_plot(
                 title = f"{y_var} vs {x_var}"
                 if show_correlation:
                     title += f" ($r$ = {r_value:.2f})"
-                ax.set_title(title)
+                # Use label_fontsize for title
+                ax.set_title(
+                    "\n".join(textwrap.wrap(title, width=text_wrap)),
+                    fontsize=label_fontsize,
+                )
                 ax.set_xlabel(
                     y_var if rotate_plot else x_var,
                     fontsize=label_fontsize,
@@ -2085,3 +2171,6 @@ def scatter_fit_plot(
         if show_plot in ["grid", "both"]:
             plt.show()  # Display the plot
         plt.close(fig)
+
+
+################################################################################
